@@ -1,11 +1,21 @@
-#' Posterior predictive check plot for survFitTT objects
+#' Posterior predictive check plot for \code{survFitTT} objects
 #'
-#' The \code{ppc} function plot the observed versus predicted values for the
-#' \code{survFitTT} objects.
+#' This is the generic \code{ppc} S3 method for the \code{survFitTT} class. It
+#' plots the predicted values with 95 \% credible intervals versus the observed
+#' values for \code{survFitTT} objects.
+#' 
+#' The coordinates of black points are the observed values of the number of survivor
+#' (poolled replicates) for a given concentration (x-scale) and the corresponding 
+#' predicted values (y-scale). 95 \% prediction intervals are added to each predicted
+#' value, colored in green if this interval contains the observed value and in red
+#' in the other case.
+#' The bisecting line (y = x) is added to the plot in order to see if each
+#' prediction interval contains each observed value. As replicates are shifted
+#' on the x-axis, this line is represented by steps.
 #'
 #' @param x An object of class \code{survFitTT}
-#' @param style Graphical package method: \code{generic} or \code{ggplot}.
-#' @param \dots Further arguments to be passed to generic methods.
+#' @param style Graphical package method: \code{generic} or \code{ggplot}
+#' @param \dots Further arguments to be passed to generic methods
 #'
 #' @examples
 #'
@@ -35,12 +45,12 @@ ppc.survFitTT <- function(x, style = "generic", ...) {
   
   xlab <- "Observed Nbr. of survivor"
   ylab <- "Predicted Nbr. of survivor"
-
+  
   ppc_gen(EvalsurvPpc(x), style, xlab, ylab)
 }
 
 ppc_gen <- function(tab, style, xlab, ylab) {
-
+  
   if (style == "generic") PpcGeneric(tab, xlab, ylab)
   else if (style == "ggplot") PpcGG(tab, xlab, ylab)
   else stop("Unknown style")
@@ -49,30 +59,31 @@ ppc_gen <- function(tab, style, xlab, ylab) {
 #' @importFrom stats rbinom quantile
 EvalsurvPpc <- function(x) {
   tot.mcmc <- do.call("rbind", x$mcmc)
-
+  
   if (x$det.part == "loglogisticbinom_3") {
-    d <- sample(tot.mcmc[, "d"], 5000)
+    d <- tot.mcmc[, "d"]
   }
-
-  b <- 10^sample(tot.mcmc[, "log10b"], 5000)
-  e <- 10^sample(tot.mcmc[, "log10e"], 5000)
-
+  
+  b <- 10^tot.mcmc[, "log10b"]
+  e <- 10^tot.mcmc[, "log10e"]
+  
+  niter <- nrow(tot.mcmc)
   n <- x$jags.data$n
   xconc <- x$jags.data$xconc
   Ninit <- x$jags.data$Ninit
   NsurvObs <- x$jags.data$Nsurv
-  NsurvPred <- matrix(NA, nrow = 5000, ncol = n)
-
+  NsurvPred <- matrix(NA, nrow = niter, ncol = n)
+  
   if (x$det.part == "loglogisticbinom_2") {
     for (i in 1:n) {
       p <- 1 / (1 + (xconc[i]/e)^b)
-      NsurvPred[, i] <- rbinom(5000, Ninit[i], p)
+      NsurvPred[, i] <- rbinom(niter, Ninit[i], p)
     }
   }
   if (x$det.part == "loglogisticbinom_3") {
     for (i in 1:n) {
       p <- d / (1 + (xconc[i]/e)^b)
-      NsurvPred[, i] <- rbinom(5000, Ninit[i], p)
+      NsurvPred[, i] <- rbinom(niter, Ninit[i], p)
     }
   }
   QNsurvPred <- t(apply(NsurvPred, 2, quantile,
@@ -83,44 +94,18 @@ EvalsurvPpc <- function(x) {
                                    QNsurvPred[,"97.5%"] < NsurvObs,
                                  "red", "green"))
   colnames(tab) <- c("P2.5", "P50", "P97.5", "Ninit", "Obs", "col")
-
+  
   return(tab)
 }
 
-stepCalc <- function(obs_val) {
-  # calculation of steps coordinate
-  sObs <- sort(obs_val)
-  stepX <- c(0, sapply(2:length(sObs), function(i) {
-    sObs[i-1] + (sObs[i] - sObs[i-1]) / 2}), max(sObs))
-  return(list(sObs = sObs, stepX = stepX))
-}
-
-jitterObsGenerator <- function(stepX, tab, obs_val) {
-  # uniform jittering of observed values
-  allSpaceX <- sapply(2:length(stepX),
-                      function(i) { stepX[i] - stepX[i-1] })
-  spaceX <- min(allSpaceX[which(allSpaceX != 0)])/2
-  lengthX <- table(tab[, "Obs"])
-  jitterObs <- mapply(function(x, y) {
-    if (y == 1) {
-      seq(x, x, length.out = y)
-    } else {
-      seq(x - spaceX + (2 * spaceX / (y + 1)),
-          x + spaceX - (2 * spaceX / (y + 1)), length.out = y)
-    }
-  }, x = sort(obs_val), y = lengthX)
-  return(list(spaceX = spaceX,
-              jitterObs = unlist(jitterObs)))
-}
-
 #' @importFrom graphics abline segments
 PpcGeneric <- function(tab, xlab, ylab) {
   obs_val <- unique(tab[, "Obs"])
   sObs <- stepCalc(obs_val)$sObs
   stepX <- stepCalc(obs_val)$stepX
-  jittered_obs <- jitterObsGenerator(stepX, tab, obs_val)$jitterObs
-  spaceX <- jitterObsGenerator(stepX, tab, obs_val)$spaceX
-
+  jittered_obs <- jitterObsGenerator(stepX, tab, obs_val, ppc = TRUE)$jitterObs
+  spaceX <- jitterObsGenerator(stepX, tab, obs_val, ppc = TRUE)$spaceX
+  
   plot(c(0, max(tab[, "P97.5"])),
        c(0, max(tab[, "P97.5"])),
        type = "n",
@@ -151,19 +136,12 @@ PpcGeneric <- function(tab, xlab, ylab) {
   }
   
   tab0 <- tab[order(tab$Obs),]
-  delta <- 0.01 * (max(obs_val) - min(obs_val))
   segments(jittered_obs, tab0[, "P2.5"],
            jittered_obs, tab0[, "P97.5"],
            col = as.character(tab0[, "col"]))
-  segments(jittered_obs - delta, tab0[, "P2.5"],
-           jittered_obs + delta, tab0[, "P2.5"],
-           col = as.character(tab0[, "col"]))
-  segments(jittered_obs - delta, tab0[, "P97.5"],
-           jittered_obs + delta, tab0[, "P97.5"],
-           col = as.character(tab0[, "col"]))
-
+  
   points(jittered_obs, tab0[, "P50"],
-         pch = 16)
+         pch = 20)
 }
 
 #' @import ggplot2
@@ -172,22 +150,18 @@ PpcGG <- function(tab, xlab, ylab) {
   obs_val <- unique(tab[, "Obs"])
   sObs <- stepCalc(obs_val)$sObs
   stepX <- stepCalc(obs_val)$stepX
-  jittered_obs <- jitterObsGenerator(stepX, tab, obs_val)$jitterObs
-  spaceX <- jitterObsGenerator(stepX, tab, obs_val)$spaceX
+  jittered_obs <- jitterObsGenerator(stepX, tab, obs_val, ppc = TRUE)$jitterObs
+  spaceX <- jitterObsGenerator(stepX, tab, obs_val, ppc = TRUE)$spaceX
   
   tab0 <- cbind(tab[order(tab$Obs),], jittered_obs)
-
-  df <- data.frame(sObs, spaceX)
   
+  df <- data.frame(sObs, spaceX)
+
   if (max(sObs) < 20) {
     gf1 <- ggplot(df) +
       geom_segment(aes(x = sObs - (spaceX * 1.25),
                        xend = sObs + (spaceX * 1.25),
-                       y = sObs, yend = sObs)) +
-      scale_x_continuous(breaks = c(0, tab0[, "Obs"]),
-                         labels = c(0, tab0[, "Obs"])) +
-      scale_y_continuous(breaks = c(0, tab0[, "Obs"]),
-                         labels = c(0, tab0[, "Obs"]))
+                       y = sObs, yend = sObs))
   } else {
     gf1 <- ggplot(tab0) +
       geom_abline(intercept = 0, slope = 1)
@@ -196,8 +170,6 @@ PpcGG <- function(tab, xlab, ylab) {
   gf2 <- gf1 +
     geom_segment(aes(x = jittered_obs, xend = jittered_obs,
                      y = P2.5, yend = P97.5), data = tab0,
-                 arrow = arrow(length = unit(0.1, "cm"), angle = 90,
-                               ends = "both"),
                  color = tab0$col) +
     geom_point(aes(x = jittered_obs, y = P50), tab0) +
     expand_limits(y = 0) +
